==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/VerticalSeparatorCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { VerticalSeparatorCellInfoDescription } from "./VerticalSeparatorCellInfoDescription";
/**
 * @hidden
 */
var VerticalSeparatorCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(VerticalSeparatorCellInfoDescriptionMetadata, _super);
    function VerticalSeparatorCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VerticalSeparatorCellInfoDescriptionMetadata.b = function (a) {
        if (VerticalSeparatorCellInfoDescriptionMetadata.a == null) {
            VerticalSeparatorCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VerticalSeparatorCellInfoDescriptionMetadata.c(VerticalSeparatorCellInfoDescriptionMetadata.a);
        }
        if (a.g(VerticalSeparatorCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.s(VerticalSeparatorCellInfoDescriptionMetadata.a);
    };
    VerticalSeparatorCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
    };
    VerticalSeparatorCellInfoDescriptionMetadata.d = function (a) {
        VerticalSeparatorCellInfoDescriptionMetadata.b(a);
        a.u("VerticalSeparatorCellInfo", function () { return new VerticalSeparatorCellInfoDescription(); });
        a.t("VerticalSeparatorCellInfo", VerticalSeparatorCellInfoDescriptionMetadata.a);
    };
    VerticalSeparatorCellInfoDescriptionMetadata.$t = markType(VerticalSeparatorCellInfoDescriptionMetadata, 'VerticalSeparatorCellInfoDescriptionMetadata');
    VerticalSeparatorCellInfoDescriptionMetadata.a = null;
    return VerticalSeparatorCellInfoDescriptionMetadata;
}(Base));
export { VerticalSeparatorCellInfoDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/VerticalSeparatorCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { VerticalSeparatorCellInfoDescription } from "./VerticalSeparatorCellInfoDescription";
/**
 * @hidden
 */
var VerticalSeparatorCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(VerticalSeparatorCellInfoDescriptionMetadata, _super);
    function VerticalSeparatorCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VerticalSeparatorCellInfoDescriptionMetadata.b = function (a) {
        if (VerticalSeparatorCellInfoDescriptionMetadata.a == null) {
            VerticalSeparatorCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VerticalSeparatorCellInfoDescriptionMetadata.c(VerticalSeparatorCellInfoDescriptionMetadata.a);
        }
        if (a.j(VerticalSeparatorCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(VerticalSeparatorCellInfoDescriptionMetadata.a);
    };
    VerticalSeparatorCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
    };
    VerticalSeparatorCellInfoDescriptionMetadata.d = function (a) {
        VerticalSeparatorCellInfoDescriptionMetadata.b(a);
        a.aa("VerticalSeparatorCellInfo", function () { return new VerticalSeparatorCellInfoDescription(); });
        a.z("VerticalSeparatorCellInfo", VerticalSeparatorCellInfoDescriptionMetadata.a);
    };
    VerticalSeparatorCellInfoDescriptionMetadata.$t = markType(VerticalSeparatorCellInfoDescriptionMetadata, 'VerticalSeparatorCellInfoDescriptionMetadata');
    VerticalSeparatorCellInfoDescriptionMetadata.a = null;
    return VerticalSeparatorCellInfoDescriptionMetadata;
}(Base));
export { VerticalSeparatorCellInfoDescriptionMetadata };
